@@ -8,6 +8,7 @@ from mercury_engine_data_structures.file_tree_editor import OutputFormat
 from open_dread_rando import elevator, lua_util, game_patches
 from open_dread_rando.cosmetic_patches import apply_cosmetic_patches
 from open_dread_rando.door_patcher import patch_door
+from open_dread_rando.environmental_damage import apply_constant_damage
 from open_dread_rando.exefs import include_depackager, patch_exefs
 from open_dread_rando.logger import LOG
 from open_dread_rando.lua_editor import LuaEditor
@@ -163,7 +164,7 @@ def patch_extracted(input_path: Path, output_path: Path, configuration: dict):
     # Text patches
     if "text_patches" in configuration:
         apply_text_patches(editor, configuration["text_patches"])
-    patch_credits(editor)
+    patch_credits(editor, configuration["spoiler_log"])
 
     # Objective
     apply_objective_patches(editor, configuration)
@@ -172,6 +173,9 @@ def patch_extracted(input_path: Path, output_path: Path, configuration: dict):
     if "cosmetic_patches" in configuration:
         apply_cosmetic_patches(editor, configuration["cosmetic_patches"])
 
+    # Environmental Damage
+    apply_constant_damage(editor, configuration["constant_environment_damage"])
+
     # Specific game patches
     game_patches.apply_game_patches(editor, configuration.get("game_patches", {}))
 
