@@ -915,6 +915,7 @@ end
 
 function s070_basesanc.OnUsableCancelUse(actor)
   Scenario.ResetGlobalTeleport(actor)
+  Scenario.CheckWarpToStart(actor)
 end
 
 function s070_basesanc.OnUsableUse(actor)
@@ -979,6 +980,8 @@ function s070_basesanc.OnSubAreaChange(old_subarea, old_actorgroup, new_subarea,
       Game.PushSetup("Post2ChozoRobots", false, true)
     end
   end
+
+  Scenario.UpdateProgressiveItemModels()
 end
 
 
